package Template::Plugin::MIB::Biblio;
use base qw(Template::Plugin);

use strict;
use warnings;
use utf8;

use Socket;
use Net::CUPS;
use Net::CUPS::Destination;

my $cups = Net::CUPS->new() or die "$@";

my $servername = "cups.math.uni-bonn.de";
$cups->setServer(inet_ntoa(inet_aton($servername)));

sub printer_status {
	my ($self, $printer) = @_;
	return -1 if $printer !~ m/^bib-.*$/;

	my $dest = $cups->getDestination($printer);
	unless ($dest) { # Verbindung neu aufbauen, möglicherweise ist CUPS umgezogen
		$cups->setServer(inet_ntoa(inet_aton($servername)));
		$dest = $cups->getDestination($printer);
	}
	return -2 unless $dest;
	return $dest->getState();
}

use Encode qw/encode decode/;
use Email::Sender::Simple;
use Email::Sender::Transport::SMTP;
use Email::Simple;
use Email::Simple::Creator;

my %mail_params = (
	'0' => { 'to_name' => 'Dr. Thoralf Räsch', to_addr => 'raesch@math.uni-bonn.de', 'subject' => '[bib-www] Allgemeine Frage' },
	'20' => { 'to_name' => 'Dr. Thoralf Räsch', to_addr => 'raesch@math.uni-bonn.de', 'subject' => '[bib-www] Kritik/Anregung' },
	'40' => { 'to_name' => 'Dr. Thoralf Räsch', to_addr => 'raesch@math.uni-bonn.de', 'subject' => '[bib-www] Kopierer, Drucker, Scanner, Internetrechner' },
	'60' => { 'to_name' => 'Fachbibliothek Mathematik', to_addr => 'bibliothek@math.uni-bonn.de', 'subject' => '[bib-www] Literaturrecherche' },
	'80' => { 'to_name' => 'Dr. Thoralf Räsch', to_addr => 'raesch@math.uni-bonn.de', 'subject' => '[bib-www] Bücherwunsch' },
	'100' => { 'to_name' => 'Dr. Thoralf Räsch', to_addr => 'raesch@math.uni-bonn.de', 'subject' => '[bib-www] Nichtfunktionierender Link/Falsche Info' },
);

my $mail_transport = Email::Sender::Transport::SMTP->new({
	host => 'smtp.math.uni-bonn.de',
	port => 25,
});

sub send_mail {
	my ($self, $cgi) = @_;
	my $type = $cgi->param('type');
	# durch accept-charset="utf-8" im post sind die CGI-Parameter garantiert UTF-8
	my $mail_param = $mail_params{$type} or return 1;
	return 3 unless $cgi->param('captcha') eq $cgi->param('captcharesult');
	my $subject = $mail_param->{'subject'} . ' // ' . decode('UTF-8', $cgi->param('subject'));
	my ($to_name, $to_addr) = ($mail_param->{'to_name'}, $mail_param->{'to_addr'});
	# Eigentlich(TM) sollte man die Mailadresse syntaktisch validieren
	my ($from_name, $from_addr) = ('Internetangebot der Fachbibliothek Mathematik // ' . decode('UTF-8', $cgi->param('name')), decode('UTF-8', $cgi->param('email')));
	$subject = encode('MIME-Header', $subject);
	my $to = encode('MIME-Header', $to_name) . '<' . $to_addr . '>';
	my $from = encode('MIME-Header', $from_name) . '<' . $from_addr . '>';
	# Email::Sender::Simple mag keine vor-umgebrochenen Header-Felder (wie sie durch das MIME-Header-encode()n auftreten) mehr,
	#  um die Warnung ("replaced vertical whitespace in From header with space; this will become fatal in a future version") loszuwerden, CRLF in SP umwandeln -- das wandelt Email::Sender::Simple dann wieder zurück.
	$subject =~ s/\r\n / /g;
	$to =~ s/\r\n / /g;
	$from =~ s/\r\n / /g;
	my $body = decode('UTF-8', $cgi->param('message'));
	my $email = Email::Simple->create(
		header => [
			To => $to,
			From => $from,
			Subject => $subject,
			"Content-Type" => 'text/plain; charset=utf-8',
		],
		body => $body,
	);
 	return Email::Sender::Simple->try_to_send($email, { transport => $mail_transport }) ? 0 : 2;
}

1;
